<?php

declare(strict_types=1);

use yii;
use yii\bootstrap\ActiveForm;

// Инициализация
if (
    !yii::$app->user->isGuest
    && yii::$app->user->identity->type === 'administrator'
    || yii::$app->user->identity->type === 'moderator'
) {
    $panel ?? $panel = 'orders_panel_moderation';
} else {
    $panel ?? $panel = 'orders_panel_orders';
}

?>

<link href="/css/pages/orders.css" rel="stylesheet">

<div id="page_orders" class="container mb-auto py-3">
    <?php if (
        !yii::$app->user->isGuest
        && yii::$app->user->identity->type === 'administrator'
        || yii::$app->user->identity->type === 'moderator'
    ) : ?>
        <div class="orders_panel_menu mb-2">
            <label class="btn button_white mb-0 mr-2" for="orders_panel_moderation">Модерация</label>
            <label class="btn button_white mb-0" for="orders_panel_orders">Мои заказы</label>
        </div>
        <input type="radio" id="orders_panel_moderation" name="main_panel" <?= $panel === 'orders_panel_moderation' ? 'checked' : null ?> />
        <article>
            <div class="orders_panel_moderation_menu mb-3">
                <label class="btn btn-sm button_white mb-0 mr-2" for="orders_panel_moderation_all">Все</label>
                <label class="btn btn-sm button_white mb-0 mr-2" for="orders_panel_moderation_requested">Запрошены</label>
                <label class="btn btn-sm button_white mb-0 mr-2" for="orders_panel_moderation_handled">Обрабатываются</label>
                <label class="btn btn-sm button_white mb-0" for="orders_panel_moderation_completed">Завершены</label>
            </div>
            <?php if (!empty($moderator_orders)) : ?>

                <?php foreach ($moderator_orders as $order) : ?>
                    <div id="<?= $order['order']['_key'] ?>_panel" class="page_order_panel mb-3 py-3 px-4 rounded">
                        <h5 class="row mt-1 mb-3">
                            <?php
                            // Инициализация времени отправки заказа
                            $date = null;

                            foreach ($order['order']['jrnl'] as $entry) {
                                // Перебор записей в журнал

                                if ($entry['action'] === 'requested') {
                                    if (empty($date) || $date <= $entry['date']) {
                                        // Буфер не инициализирован или в него записано более старое событие

                                        // Запись
                                        $date = $entry['date'];
                                    }
                                }
                            }

                            $date = [
                                'H:i' => date('H:i', $date),
                                'm.d.Y' =>  date('m.d.Y', $date)
                            ];

                            ?>
                            <p class="col-auto ml-1">#<?= $order['order']['_key'] ?></p>
                            <p class="col-auto mr-1">
                                <span class="mr-2"><?= $date['H:i'] ?? 'Неизвестно' ?></span>
                                <span><?= $date['m.d.Y'] ?? 'Неизвестно' ?></span>
                            </p>
                        </h5>
                        <div class="dropdown-divider mb-3"></div>
                        <div class="row px-2">
                            <div id="orders_panel_supplies_<?= $order['order']['_key'] ?>" class="col-3 unselectable">
                                <?php if (!empty($order['supplies'])) : ?>
                                    <?php
                                    // Инициализация счетчика поставок для отрисовки горизонтального разделителя
                                    $count = 1;
                                    ?>

                                    <?php foreach ($order['supplies'] as $supply) : ?>
                                        <?php

                                        // Инициализация обложки
                                        $covr = null;

                                        foreach ($imgs ?? [] as $img) {
                                            // Перебор изображений для обложки

                                            if ($img['covr'] ?? false) {
                                                // Обложка найдена

                                                $covr = $img['h150'];

                                                break;
                                            }
                                        }

                                        if (is_null($covr)) {
                                            // Обложка не инициализирована

                                            if (!$covr = $imgs[0]['h150'] ?? false) {
                                                // Не удалось использовать первое изображение как обложку

                                                // Запись обложки по умолчанию
                                                $covr = '/img/covers/h150/product.png';
                                            }
                                        }

                                        ?>

                                        <?php foreach ($supply['order_edge_supply'] as $part) : ?>
                                            <a id="<?= $part['_key'] ?>_supply" class="row p-2 px-0 rounded row_supply" type="button" onclick="return orders_supply_edit('<?= $part['_key'] ?>', <?= $order['order']['_key'] ?>);">
                                                <img class="col-auto px-0 h-100 img-fluid rounded" src="<?= $covr ?>" />
                                                <p id="<?= $part['_key'] ?>_supply_stts_indicator" class="col d-flex text-dark"><?= $supply['product']['catn'] ?>
                                                    <?php if(isset($part['stts']) && $part['stts'] == 1) :?>
                                                        <span id="<?= $part['_key'] ?>_supply_stts_indicator_icon" class="ml-auto my-auto fas fa-check"></span>
                                                    <?php endif ?>
                                                </p>
                                            </a>
                                        <?php endforeach ?>

                                        <?php if ($count++ < count($order['supplies'])) : ?>
                                            <div class="dropdown-divider mb-2"></div>
                                        <?php endif ?>
                                    <?php endforeach ?>
                                <?php else : ?>
                                    <div class="row">
                                        <p>Поставки не найдены</p>
                                    </div>
                                <?php endif ?>
                            </div>
                            <div id="orders_panel_edit_<?= $order['order']['_key'] ?>" class="px-3 col-6 d-flex flex-column">
                                <p class="my-auto">Выберите поставку</p>
                            </div>
                            <div id="orders_panel_info_<?= $order['order']['_key'] ?>" class="col-3 d-flex flex-column">

                                <?php
                                // Конвертация статуса заказа
                                $status = match ($order['account_edge_order'][0]['type']) {
                                    'requested' => 'Запрошен',
                                    'handled' => 'Обрабатывается',
                                    'completed' => 'Завершен',
                                }
                                ?>

                                <p class="row mt-0 mb-3 px-2"><b>Статус:</b> <span class="ml-auto"><?= $status ?></span></p>
                                <a id="<?= $order['order']['_key'] ?>_button" class="row mt-auto mb-0 text-center text-white btn button_blue button_clean disabled" type="button" onclick="return order_accept('<?= $order['order']['_key'] ?>');">Подтвердить</a>
                            </div>
                        </div>
                        <script>
                            document.addEventListener('DOMContentLoaded', function() {

                                order_init('<?= $order['order']['_key'] ?>');

                            }, false);
                        </script>
                    </div>
                <?php endforeach ?>
            <?php else : ?>
                <div class="page_order_panel py-3 px-4 rounded">
                    <p class="text-center">Заказов нет</p>
                </div>
            <?php endif ?>
        </article>

        <input type="radio" id="orders_panel_orders" name="main_panel" <?= $panel === 'orders_panel_orders' ? 'checked' : null ?> />
    <?php endif ?>
    <article class="page_order_panel mt-3 py-3 px-4 rounded">
        <h4 class="ml-4 mt-2 mb-4"><i class="fas fa-list mr-2"></i>Заказы</h4>
        <div class="col mb-4 list rounded overflow-hidden">
            <div class="row py-2">
                <div class="pl-3 mr-1">
                    <input id="checkbox_cart_all" type="checkbox" onchange="return cart_list_checkbox(this);" />
                </div>
                <div class="col-2 ml-auto">
                    <span>Статус</span>
                </div>
                <div class="col-2 mr-3 text-right">
                    <span>Время</span>
                </div>
            </div>
            <?php

            if (isset($orders) && !empty($orders)) {
                foreach ($orders as $order) {
                    // Перебор заказов

                    // Инициализация
                    extract($order);

                    // Инициализация
                    $date = empty($jrnl) ? '' : date('H:i d.m.Y', end($jrnl)['date']);

                    echo <<<HTML
                        <div class="row py-2 cart_list_target">
                            <div class="pl-3 mr-1">
                                <input type="checkbox" onchange="return cart_list_checkbox(this);"/>
                            </div>
                            <div class="col-2 ml-auto">
                                {$account_edge_order[0]['type']}
                            </div>
                            <div class="col-2 mr-3 text-right">
                               $date
                            </div>
                        </div>
                    HTML;
                }
            } else {
                echo <<<HTML
                    <div class="row py-2 cart_list_target">
                        <div class="mx-auto py-2">
                            Заказов нет
                        </div>
                    </div>
                HTML;
            }
            ?>
        </div>
        <div class="row mb-2 mx-0">
            <select id="cart_list_action" class="form-control mr-3 button_clean w-auto" name="CartListAction">
                <option value="none" hidden>Действие с выбранными</option>
                <option value="delete" onclick="return cart_list_delete();">Удалить</option>
            </select>
        </div>
    </article>
</div>

<script src="/js/orders.js" defer></script>
<?php if (
    !yii::$app->user->isGuest
    && (yii::$app->user->identity->type === 'administrator'
        || yii::$app->user->identity->type === 'moderator')
) : ?>
    <script src="/js/orders_panel.js" defer></script>
<?php endif ?>
