<?php

declare(strict_types=1);

use yii;
use yii\bootstrap\ActiveForm;
use yii\helpers\Html;

use app\models\Notification;

// Инициализация
$panel ?? $panel = 'profile_panel_panel_input_notifications';

?>

<link href="/css/pages/profile.css" rel="stylesheet">

<div id="page_profile" class="container mb-auto">
    <div class="row h-100 py-3">
        <nav class="col-3">
            <?= $sidebar ?? yii::$app->controller->renderPartial('/profile/sidebar') ?>
        </nav>
        <article class="col-9">
            <div class="p-4 rounded">
                <h4 class="ml-4 mb-4"><i class="fas fa-user-shield my-auto mr-2"></i>Панель управления</h4>
                <div id="profile_panel_panel" class="profile_panel">
                    <div class="profile_panel_menu mb-3">
                        <label class="btn button_white mb-0 mr-2" for="profile_panel_panel_input_notifications">Уведомления</label>
                        <label class="btn button_white mb-0 mr-2" for="profile_panel_panel_input_settings">Настройки</label>
                    </div>
                    <div class="profile_panel_content">
                        <input type="radio" id="profile_panel_panel_input_notifications" name="main_panel" <?= $panel === 'profile_panel_panel_input_notifications' ? 'checked' : null ?> />
                        <div class="col">
                            <h5>Отправка уведомления</h5>
                            <div class="dropdown-divider mb-3"></div>
                            <?php
                            $form = ActiveForm::begin([
                                'id' => 'form_profile_panel_notifications',
                                'action' => false,
                                'fieldConfig' => [
                                    'template' => '{label}{input}'
                                ],
                                'options' => [
                                    'onsubmit' => 'return false;'
                                ]
                            ]);

                            // Значения по умолчанию
                            $model_notifications ?? $model_notifications = new Notification;
                            $model_notifications->account ?? $model_notifications->account = null;
                            $model_notifications->text ?? $model_notifications->text = '';
                            ?>

                            <?= $form->errorSummary($model_notifications) ?>

                            <div class="row">
                                <?= $form->field($model_notifications, 'account', ['options' => ['class' => "mb-1 col-9"]])->input('text', ['placeholder' => yii::$app->user->identity->_key]); ?>
                                <?= $form->field($model_notifications, 'type', ['options' => ['class' => "col pl-0"]])->dropDownList($model_notifications->typs); ?>
                            </div>
                            <small class="d-block mb-1"><b>Множественная отправка:</b> @all или перечислить через запятую</small>
                            <small class="d-block mb-3"><b>Тестирование:</b> @test или оставить поле пустым</small>

                            <?= $form->field($model_notifications, 'text', ['options' => ['class' => "mb-1"]])->textarea(["maxlength" => '300']); ?>

                            <p class="mb-3 text-right">
                                <span id="notification-text-current">0</span>
                                <span> / </span>
                                <span id="notification-text-maximum">300</span>
                            </p>

                            <?= Html::submitButton('Отправить', ['name' => 'submitNotification', 'onclick' => 'page_profile_panel_notification_create(this.parentElement);', 'id' => 'notification-button-send', 'class' => 'flex-grow-1 mr-2 btn button_white button_clean']) ?>
                            <?= Html::submitButton('Отправить как HTML', ['name' => 'submitNotification', 'onclick' => 'page_profile_panel_notification_create(this.parentElement, 1);', 'id' => 'notification-button-send-html', 'class' => 'flex-grow-1 mr-2 btn button_white button_clean']) ?>

                            <?php ActiveForm::end(); ?>
                        </div>

                        <input type="radio" id="profile_panel_panel_input_settings" name="main_panel" <?= $panel === 'profile_panel_panel_input_settings' ? 'checked' : null ?> />
                        <div class="col">
                            <?php
                            $form = ActiveForm::begin([
                                'id' => 'form_profile_panel_settings_search_period',
                                'action' => false,
                                'fieldConfig' => [
                                    'template' => '{label}{input}',
                                ],
                                'options' => [
                                    'onsubmit' => 'return false;',
                                    'class' => 'mb-4'
                                ]
                            ]);
                            ?>

                            <?= $form->errorSummary($model_settings, ['header' => 'Получены ошибки:']) ?>

                            <?= $form->field($model_settings, 'search_period', ['options' => ['class' => "mb-1"]])->textInput(['value' => $model_settings['search_period'], 'onChange' => 'page_profile_panel_settings(this.parentElement.parentElement, \'profile_panel_panel_input_settings\')']); ?>
                            <small class="d-block mb-1">Время которое надо ждать для повторного поиска в секундах</small>

                            <?php ActiveForm::end(); ?>

                            <?php
                            $form = ActiveForm::begin([
                                'id' => 'form_profile_panel_settings_search_connect_keep',
                                'action' => false,
                                'fieldConfig' => [
                                    'template' => '{label}{input}',
                                ],
                                'options' => [
                                    'onsubmit' => 'return false;'
                                ]
                            ]);

                            $list = ['false' => 'Нет', 'true' => 'Да'];

                            if (isset($model_settings->search_connect_keep)) {
                                // Найден ранее записанный параметр

                                if (isset($list[$model_settings->search_connect_keep])) {
                                    // Совпадение параметра с параметрами списка найдено

                                    // Буфер для сохранения параметра
                                    $buffer = $list[$model_settings->search_connect_keep];

                                    // Удаление параметра
                                    unset($list[$model_settings->search_connect_keep]);

                                    // Сохранение параметра в начале массива
                                    $list = array_merge([$model_settings->search_connect_keep => $buffer], $list);
                                } else {
                                    // Совпадение параметра с параметрами списка не найдено

                                    // Сохранение параметра из данных аккаунта в начале массива
                                    $list = array_merge([$model_settings->search_connect_keep => $model_settings->search_connect_keep], $list);
                                }
                            }
                            ?>

                            <?= $form->field($model_settings, 'search_connect_keep', ['options' => ['class' => "mb-1"]])->dropDownList($list, ['onChange' => 'page_profile_panel_settings(this.parentElement.parentElement, \'profile_panel_panel_input_settings\')']); ?>
                            <small class="d-block mb-1">Удерживать открытое соединение до истечения срока блокировки поиска?</small>
                            <small class="d-block mb-1">При малой задержке позволяет снизить время загрузки страницы, но при большой будет казаться, что сайт завис</small>

                            <?php ActiveForm::end(); ?>
                        </div>
                    </div>
                </div>
            </div>
        </article>
    </div>
</div>

<script src="/js/profile.js" defer></script>
<script src="/js/profile_panel.js" defer></script>
<script src="/js/textarea.js" defer></script>
<script defer>
    document.addEventListener('DOMContentLoaded', function() {
        initTextarea(
            '#notification-text',
            '#notification-text-current',
            '#notification-text-maximum',
            function() {
                let send = document.getElementById('notification-button-send');
                let send_html = document.getElementById('notification-button-send-html');

                send.removeAttribute('onchange');
                send_html.removeAttribute('onchange');

                send.disabled = true;
                send_html.disabled = true;
            },
            function() {
                let send = document.getElementById('notification-button-send');
                let send_html = document.getElementById('notification-button-send-html');

                send.setAttribute('onchange', 'page_profile_panel_notification_create(this.parentElement);');
                send_html.setAttribute('onchange', 'page_profile_panel_notification_create(this.parentElement, 1);');

                send.disabled = false;
                send_html.disabled = false;
            });
    }, false);
</script>
